import { T as TestFactory, S as SuiteCollector, a as TestFunction, b as SuiteHooks, U as UserOptions } from './types-53cd5eeb';
export { C as ComputeMode, F as File, G as GlobalContext, H as HookListener, M as ModuleCache, l as Reporter, R as ResolvedConfig, n as RpcCall, m as RpcMap, p as RpcPayload, o as RpcSend, c as RunMode, h as Suite, S as SuiteCollector, b as SuiteHooks, j as Task, e as TaskBase, f as TaskResult, g as TaskResultPack, d as TaskState, i as Test, k as TestCollector, T as TestFactory, a as TestFunction, U as UserOptions, V as VitestContext, W as WorkerContext } from './types-53cd5eeb';
export { assert, default as chai, expect, should } from 'chai';
import sinon from 'sinon';
export { default as sinon } from 'sinon';
import 'worker_threads';
import '@antfu/utils';
import 'vite';
import 'jest-snapshot/build/State';

declare const suite: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const defaultSuite: SuiteCollector;
declare function createSuiteHooks(): {
    beforeAll: never[];
    afterAll: never[];
    beforeEach: never[];
    afterEach: never[];
};
declare const test: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const describe: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const it: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const beforeAll: (fn: SuiteHooks['beforeAll'][0], timeout?: number) => void;
declare const afterAll: (fn: SuiteHooks['afterAll'][0], timeout?: number) => void;
declare const beforeEach: (fn: SuiteHooks['beforeEach'][0], timeout?: number) => void;
declare const afterEach: (fn: SuiteHooks['afterEach'][0], timeout?: number) => void;
declare function clearContext(): void;

declare const mock: sinon.SinonMockStatic;
declare const spy: sinon.SinonSpyStatic;
declare const stub: sinon.SinonStubStatic;

declare module 'vite' {
    interface UserConfig {
        /**
         * Options for Vitest
         */
        test?: UserOptions;
    }
}
declare global {
    namespace Chai {
        interface Assertion {
            toMatchSnapshot(message?: string): Assertion;
            matchSnapshot(message?: string): Assertion;
            toEqual(expected: any): void;
            toStrictEqual(expected: any): void;
            toBe(expected: any): void;
            toMatch(expected: string | RegExp): void;
            toMatchObject(expected: any): void;
            toContain(item: any): void;
            toContainEqual(item: any): void;
            toBeTruthy(): void;
            toBeFalsy(): void;
            toBeNaN(): void;
            toBeUndefined(): void;
            toBeNull(): void;
            toBeDefined(): void;
            toBeInstanceOf(c: any): void;
            toHaveBeenCalledTimes(n: number): void;
            toHaveBeenCalledOnce(): void;
            toHaveBeenCalled(): void;
            toHaveBeenCalledWith(...args: any[]): void;
        }
    }
}

export { afterAll, afterEach, beforeAll, beforeEach, clearContext, createSuiteHooks, defaultSuite, describe, it, mock, spy, stub, suite, test };
